==> semantic_comparison_network-1.0.5.tar.gz: semantic_comparison_network-1.0.5/setup.py <==
# Semantic Comparison Network (SCN) is a new artificial neural network architecture based on the HurNet network. The semantic comparison network architecture also utilizes semantic comparison calculations and Euclidean distance for feature expansion.
# The SCN focuses on language model development and employs a significantly faster training approach compared to traditional transformer-based architectures. This algorithm was created, designed, and developed by Sapiens Technology®️, and any sharing, disclosure,          
# or public commentary on the logic involved in this code without our prior authorization is strictly prohibited and subject to legal action by our team of attorneys. All copyright rights to this algorithm are under the guardianship of Sapiens Technology®️,
# and we do not permit any modification, customization, or enhancement of the original code.
from setuptools import setup, find_packages
package_name = 'semantic_comparison_network'
version = '1.0.5'
setup(
    name=package_name,
    version=version,
    author='SAPIENS TECHNOLOGY',
    packages=find_packages(),
    install_requires=['numpy==1.25.2', 'tiktoken==0.4.0', 'hurnet==1.0.8', 'tqdm==4.67.1'],
    url='https://github.com/sapiens-technology/semantic_comparison_network',
    license='Proprietary Software'
)
# Semantic Comparison Network (SCN) is a new artificial neural network architecture based on the HurNet network. The semantic comparison network architecture also utilizes semantic comparison calculations and Euclidean distance for feature expansion.
# The SCN focuses on language model development and employs a significantly faster training approach compared to traditional transformer-based architectures. This algorithm was created, designed, and developed by Sapiens Technology®️, and any sharing, disclosure,          
# or public commentary on the logic involved in this code without our prior authorization is strictly prohibited and subject to legal action by our team of attorneys. All copyright rights to this algorithm are under the guardianship of Sapiens Technology®️,
# and we do not permit any modification, customization, or enhancement of the original code.

==> semantic_comparison_network-1.0.6.tar.gz: semantic_comparison_network-1.0.6/setup.py <==
# Semantic Comparison Network (SCN) is a new artificial neural network architecture based on the HurNet network. The semantic comparison network architecture also utilizes semantic comparison calculations and Euclidean distance for feature expansion.
# The SCN focuses on language model development and employs a significantly faster training approach compared to traditional transformer-based architectures. This algorithm was created, designed, and developed by Sapiens Technology®️, and any sharing, disclosure,          
# or public commentary on the logic involved in this code without our prior authorization is strictly prohibited and subject to legal action by our team of attorneys. All copyright rights to this algorithm are under the guardianship of Sapiens Technology®️,
# and we do not permit any modification, customization, or enhancement of the original code.
from setuptools import setup, find_packages
package_name = 'semantic_comparison_network'
version = '1.0.6'
setup(
    name=package_name,
    version=version,
    author='SAPIENS TECHNOLOGY',
    packages=find_packages(),
    install_requires=['numpy', 'tiktoken', 'hurnet', 'tqdm'],
    url='https://github.com/sapiens-technology/semantic_comparison_network',
    license='Proprietary Software'
)
# Semantic Comparison Network (SCN) is a new artificial neural network architecture based on the HurNet network. The semantic comparison network architecture also utilizes semantic comparison calculations and Euclidean distance for feature expansion.
# The SCN focuses on language model development and employs a significantly faster training approach compared to traditional transformer-based architectures. This algorithm was created, designed, and developed by Sapiens Technology®️, and any sharing, disclosure,          
# or public commentary on the logic involved in this code without our prior authorization is strictly prohibited and subject to legal action by our team of attorneys. All copyright rights to this algorithm are under the guardianship of Sapiens Technology®️,
# and we do not permit any modification, customization, or enhancement of the original code.
